aboutsummaryrefslogtreecommitdiffstats
path: root/home/give.asm
diff options
context:
space:
mode:
authorRangi <remy.oukaour+rangi42@gmail.com>2021-08-28 17:02:20 -0400
committerRangi <remy.oukaour+rangi42@gmail.com>2021-08-28 17:02:20 -0400
commit7ee8a6509e323ec012ece6273809e46830c29239 (patch)
treea58c8343919f9be0f208733f77506d783e5c269c /home/give.asm
parentRemove old tile animation comments (#333) (diff)
downloadpokeyellow-7ee8a6509e323ec012ece6273809e46830c29239.tar.gz
pokeyellow-7ee8a6509e323ec012ece6273809e46830c29239.tar.xz
pokeyellow-7ee8a6509e323ec012ece6273809e46830c29239.zip
wcf4b -> wStringBuffer
Diffstat (limited to 'home/give.asm')
-rw-r--r--home/give.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/home/give.asm b/home/give.asm
index cbfd0310..f446cf36 100644
--- a/home/give.asm
+++ b/home/give.asm
@@ -1,6 +1,6 @@
GiveItem::
; Give player quantity c of item b,
; and copy the item's name to wcf4b.
; Return carry on success.
ld a, b
ld [wd11e], a
@@ -11,7 +11,7 @@ GiveItem::
call AddItemToInventory
ret nc
call GetItemName
- call CopyStringToCF4B
+ call CopyToStringBuffer
scf
ret
@@ -1,6 +1,6 @@
GiveItem::
; Give player quantity c of item b,
-; and copy the item's name to wcf4b.
+; and copy the item's name to wStringBuffer.
; Return carry on success.
ld a, b